@@ -152,7 +152,7 @@ class GptManager:
                                      "request_data_list":None,
                                      "completion_percentage":None,
                                      "chunk_type":"CODE"}
-        self.navigation_mgr= AbstractNavigationManager(self,window_mgr=self.window_mgr,)
+        self.navigation_mgr= AbstractNavigationManager(self,window_mgr=self.window_mgr)
         self.browser_mgr = AbstractBrowser(window_mgr=self)
         self.next_read_mgr=NextReadManager()
         self.thread_mgr = ThreadManager()
@@ -483,9 +483,10 @@ class GptManager:
         if self.event in self.section_navigation_keys+self.sub_navigation_keys:
             nav_type, nav_direction=self.navigation_mgr.parse_navigation_event(self.event)
             nav_data=self.navigation_mgr.get_navigation_data(nav_type)
-            sub_section_number = self.navigation_mgr.get_sub_section_number(nav_type)
-            refference_object = self.navigation_mgr.get_reference_object(nav_type)
-            self.navigation_mgr.update_navigation_counters(nav_data, nav_direction)
+            if nav_data != None:
+                sub_section_number = self.navigation_mgr.get_sub_section_number(nav_type)
+                refference_object = self.navigation_mgr.get_reference_object(nav_type)
+                self.navigation_mgr.update_navigation_counters(nav_data, nav_direction)
 
         elif self.event in ['-REDO_CHUNKS-',
                             '-ADD_URL_TO_CHUNK-',
@@ -1147,7 +1148,6 @@ class GptManager:
         self.right_click_mgr.right_click_event(event,values,window)
         
     def while_window(self,event,values,window):
-        print(event)
         self.event,self.values,window=event,values,window
         if self.loop_one == False:
             
